# dopynion

Dominion in Python

## TODO

- nouvelles cartes
  - faciles :
    - sunkentreasure : il faut regarder les règles (les règles papier ne disent pas si le trésor compte quand on a appliqué son effet) et quand on la joue ?
    - anvil : il faut regarder les règles (les règles papier ne disent pas si le trésor compte quand on a appliqué son effet) et quand on la joue ?
    - charlatan : un peu plus dure
    - courier
    - lostcity : faire une action au moment de l'achat…
    - magpie
    - marquis
    - port
  - moyennes:
    - stronghold : au prochain tour
    - dungeon : au prochain tour
    - swamphag : au prochain tour, durant le tour
    - warlord : au prochain tour, durant le tour
    - galleria : durant le tour
    - skirmisher : durant le tour
    - territory : il faut connaître les différents types de cartes victoire
    - town : au choix parmis plusieurs options
    - blacksmith : au choix parmis plusieurs options
    - capitalcity : au choix parmis plusieurs options
    - hillfort : au choix parmis plusieurs options
    - innkeeper : au choix parmis plusieurs options
    - investment : au choix parmis plusieurs options
    - modification : au choix parmis plusieurs options
    - archer : communication à double sens
    - tiara : jouer deux fois un carte
    - specialist : pas clair, et jouer deux fois une carte

- afficher dans les log le résultat des hooks
- dans le site, mettre l'ordre des joueurs en fonction du score dans les anciennes parties
- checker les identifiants de partie renvoyés par les API
- s'assurer que les stratégies random fonctionnent avec des parties en simultané
- afficher les noms des équipes sur le leader board et le graphe
- purger les anciens games automatiquement sur le serveur
- pour l'année prochaine, prévoir une apparition progressive des cartes
